@@ -1,10 +1,19 @@
 import re
+import errno
 import uasyncio as asyncio
 import utemplate.source
 
 from .utils import parse_qs
 
 
+def get_mime_type(fname):
+    # Provide minimal detection if important file
+    # types to keep browsers happy
+    if fname.endswith(".html"):
+        return "text/html"
+    if fname.endswith(".css"):
+        return "text/css"
+    return "text/plain"
 
 def sendfd(writer, f):
     while True:
@@ -13,10 +22,18 @@ def sendfd(writer, f):
             break
         yield from writer.awrite(buf)
 
-def sendfile(writer, fname, content_type="text/plain"):
-    yield from start_response(writer, content_type)
-    with open(fname) as f:
-        yield from sendfd(writer, f)
+def sendfile(writer, fname, content_type=None):
+    if not content_type:
+        content_type = get_mime_type(fname)
+    try:
+        with open(fname, "rb") as f:
+            yield from start_response(writer, content_type)
+            yield from sendfd(writer, f)
+    except OSError as e:
+        if e.args[0] == errno.ENOENT:
+            yield from start_response(writer, "text/plain", "404")
+        else:
+            raise
 
 def jsonify(writer, dict):
     import ujson
